@@ -60,6 +60,13 @@ sub shift : method {
         CORE::shift @{$reader->($_[0])} 
     };
 }
+
+sub clear : method {
+    my ($attr, $reader, $writer) = @_;
+    return sub { 
+        @{$reader->($_[0])} = ()
+    };
+}
    
 sub get : method {
     my ($attr, $reader, $writer) = @_;
@@ -127,6 +134,8 @@ see those provied methods, refer to that documentation.
 
 =item B<unshift>
 
+=item B<clear>
+
 =back
 
 =head1 BUGS
